[gtk+/gtk-style-context: 374/533] GtkThemingEngine: Do not use possible reserved word.



commit df858883e4abb27161a1dcc9071c5bef9212a4bd
Author: Carlos Garnacho <carlosg gnome org>
Date:   Sun Nov 14 19:47:09 2010 +0100

    GtkThemingEngine: Do not use possible reserved word.

 gtk/gtkthemingengine.c |   14 +++++++-------
 gtk/gtkthemingengine.h |    2 +-
 2 files changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/gtk/gtkthemingengine.h b/gtk/gtkthemingengine.h
index 784737f..ee443d6 100644
--- a/gtk/gtkthemingengine.h
+++ b/gtk/gtkthemingengine.h
@@ -171,7 +171,7 @@ GType gtk_theming_engine_get_type (void) G_GNUC_CONST;
 void _gtk_theming_engine_set_context (GtkThemingEngine *engine,
                                       GtkStyleContext  *context);
 
-void gtk_theming_engine_register_property (const gchar            *namespace,
+void gtk_theming_engine_register_property (const gchar            *name_space,
                                            GtkStylePropertyParser  parse_func,
                                            GParamSpec             *pspec);
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkthemingengine.c b/gtk/gtkthemingengine.c
index 8a29167..6951581 100644
--- a/gtk/gtkthemingengine.c
+++ b/gtk/gtkthemingengine.c
@@ -327,14 +327,14 @@ _gtk_theming_engine_set_context (GtkThemingEngine *engine,
 /**
  * gtk_theming_engine_register_property:
  * @engine: a #GtkThemingEngine
  * @namespace: namespace for the property name
  * @parse_func: parsing function to use, or %NULL
  * @pspec: the #GParamSpec for the new property
  *
  * Registers a property so it can be used in the CSS file format,
  * on the CSS file the property will look like
  * "-${ namespace}-${property_name}". being
  * ${property_name} the given to @pspec. @namespace will usually
  * be the theme engine name.
  *
  * For any type a @parse_func may be provided, being this function
@@ -366,18 +366,18 @@ _gtk_theming_engine_set_context (GtkThemingEngine *engine,
  * Since: 3.0
  **/
 void
-gtk_theming_engine_register_property (const gchar            *namespace,
+gtk_theming_engine_register_property (const gchar            *name_space,
                                       GtkStylePropertyParser  parse_func,
                                       GParamSpec             *pspec)
 {
   gchar *name;
 
-  g_return_if_fail (namespace != NULL);
-  g_return_if_fail (strchr (namespace, ' ') == NULL);
+  g_return_if_fail (name_space != NULL);
+  g_return_if_fail (strchr (name_space, ' ') == NULL);
   g_return_if_fail (G_IS_PARAM_SPEC (pspec));
 
   /* FIXME: hack hack hack, replacing pspec->name to include namespace */
-  name = g_strdup_printf ("-%s-%s", namespace, pspec->name);
+  name = g_strdup_printf ("-%s-%s", name_space, pspec->name);
   g_free (pspec->name);
   pspec->name = name;
 
@@ -327,14 +327,14 @@ _gtk_theming_engine_set_context (GtkThemingEngine *engine,
  * gtk_theming_engine_register_property:
  * @engine: a #GtkThemingEngine
- * @namespace: namespace for the property name
+ * @name_space: namespace for the property name
  * @parse_func: parsing function to use, or %NULL
  * @pspec: the #GParamSpec for the new property
@@ -327,14 +327,14 @@ _gtk_theming_engine_set_context (GtkThemingEngine *engine,
  * Registers a property so it can be used in the CSS file format,
  * on the CSS file the property will look like
- * "-${ namespace}-${property_name}". being
- * ${property_name} the given to @pspec. @namespace will usually
+ * "-${ name_space}-${property_name}". being
+ * ${property_name} the given to @pspec. @name_space will usually
  * be the theme engine name.
  *